/* OscThread -- thread for making an oscillator go go go
 *	this one has a filter!
 *
 * 		Brad Garton, spring 2003
 *
*/
import com.softsynth.jsyn.*;

class OscThread extends Thread
{
	SawtoothOscillator	theOsc;
	SynthEnvelope		theEnv;
	EnvelopePlayer		theEnvPlayer;
	double [] envdata =
	{
		0.0, 0.0,
		0.5, 1.0,
		0.5, 0.0
	};
	MultiplyUnit		theMult;
	LineOut			oscOut;

	public OscThread() throws SynthException
	{
		theOsc = new SawtoothOscillator();

		// envdata has already been set up
		theEnv = new SynthEnvelope(envdata);
		theEnvPlayer = new EnvelopePlayer();

		theMult = new MultiplyUnit();
		oscOut = new LineOut();

		// connect 'em up!
		theOsc.output.connect(theMult.inputA);
		theEnvPlayer.output.connect(theMult.inputB);

		theMult.output.connect(0, oscOut.input, 0);
		theMult.output.connect(0, oscOut.input, 1);

		theOsc.amplitude.set(0.5);
		theOsc.frequency.set(252.0);
	}

	public void run()
	{
		try
		{
			// we start() the units and they run continuously,
			// but we will only hear sound when the SynthEnvelope
			// is queue'd in the go() method below
			theOsc.start();
			theEnvPlayer.start();
			theMult.start();
			oscOut.start();
		} catch(SynthException e) {
			SynthAlert.showError(e);
		}
	}

	public void go()
	{
		try
		{
			// this will trigger the amplitude envelope
			theEnvPlayer.envelopePort.clear();
			theEnvPlayer.envelopePort.queue(theEnv);
		} catch(SynthException e) {
			SynthAlert.showError(e);
		}
	}
}
